@@ -5,3 +5,6 @@ from .composition_bounds import CompositionBounds
 from .integer_bounds import IntegerBounds
 from .molecular_structure_bounds import MolecularStructureBounds
 from .real_bounds import RealBounds
+
+__all__ = ["RealBounds", "IntegerBounds", "CategoricalBounds", "CompositionBounds",
+           "MolecularStructureBounds"]
